# JAAQL-middleware-python
Please navigate to docker/docker.md to see setup instructions  

The project can be deployed alone to function as a database portal or extended as shown in the example app located at https://github.com/JAAQL/JAAQL-example-app  
